==> istio-model-v1alpha3-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsFluentImpl<A extends LoadBalancerSettingsFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsFluent<A>{
  public LoadBalancerSettingsFluentImpl() {
  }
  public LoadBalancerSettingsFluentImpl(LoadBalancerSettings instance) {
    this.withLbPolicy(instance.getLbPolicy()); 
    this.withLocalityLbSetting(instance.getLocalityLbSetting()); 
  }
  private VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> lbPolicy;
  private LocalityLoadBalancerSettingBuilder localityLbSetting;
  
  /**
   * This method has been deprecated, please use method buildLbPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsLoadBalancerSettingsLbPolicy getLbPolicy() {
    return this.lbPolicy!=null?this.lbPolicy.build():null;
  }
  public IsLoadBalancerSettingsLbPolicy buildLbPolicy() {
    return this.lbPolicy!=null?this.lbPolicy.build():null;
  }
  public A withLbPolicy(IsLoadBalancerSettingsLbPolicy lbPolicy) {
    if (lbPolicy instanceof LoadBalancerSettingsSimple){ this.lbPolicy= new LoadBalancerSettingsSimpleBuilder((LoadBalancerSettingsSimple)lbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);}
    if (lbPolicy instanceof LoadBalancerSettingsConsistentHash){ this.lbPolicy= new LoadBalancerSettingsConsistentHashBuilder((LoadBalancerSettingsConsistentHash)lbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);}
    return (A) this;
  }
  public Boolean hasLbPolicy() {
    return this.lbPolicy != null;
  }
  public A withLoadBalancerSettingsSimpleLbPolicy(LoadBalancerSettingsSimple loadBalancerSettingsSimpleLbPolicy) {
    _visitables.get("lbPolicy").remove(this.lbPolicy);
    if (loadBalancerSettingsSimpleLbPolicy!=null){ this.lbPolicy= new LoadBalancerSettingsSimpleBuilder(loadBalancerSettingsSimpleLbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);} else { this.lbPolicy = null; _visitables.get("lbPolicy").remove(this.lbPolicy); } return (A) this;
  }
  public LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicy() {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNestedImpl();
  }
  public LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicyLike(LoadBalancerSettingsSimple item) {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNestedImpl(item);
  }
  public A withLoadBalancerSettingsConsistentHashLbPolicy(LoadBalancerSettingsConsistentHash loadBalancerSettingsConsistentHashLbPolicy) {
    _visitables.get("lbPolicy").remove(this.lbPolicy);
    if (loadBalancerSettingsConsistentHashLbPolicy!=null){ this.lbPolicy= new LoadBalancerSettingsConsistentHashBuilder(loadBalancerSettingsConsistentHashLbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);} else { this.lbPolicy = null; _visitables.get("lbPolicy").remove(this.lbPolicy); } return (A) this;
  }
  public LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicy() {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNestedImpl();
  }
  public LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicyLike(LoadBalancerSettingsConsistentHash item) {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNestedImpl(item);
  }
  
  /**
   * This method has been deprecated, please use method buildLocalityLbSetting instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalityLoadBalancerSetting getLocalityLbSetting() {
    return this.localityLbSetting!=null ?this.localityLbSetting.build():null;
  }
  public LocalityLoadBalancerSetting buildLocalityLbSetting() {
    return this.localityLbSetting!=null ?this.localityLbSetting.build():null;
  }
  public A withLocalityLbSetting(LocalityLoadBalancerSetting localityLbSetting) {
    _visitables.get("localityLbSetting").remove(this.localityLbSetting);
    if (localityLbSetting!=null){ this.localityLbSetting= new LocalityLoadBalancerSettingBuilder(localityLbSetting); _visitables.get("localityLbSetting").add(this.localityLbSetting);} else { this.localityLbSetting = null; _visitables.get("localityLbSetting").remove(this.localityLbSetting); } return (A) this;
  }
  public Boolean hasLocalityLbSetting() {
    return this.localityLbSetting != null;
  }
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> withNewLocalityLbSetting() {
    return new LoadBalancerSettingsFluentImpl.LocalityLbSettingNestedImpl();
  }
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> withNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return new LoadBalancerSettingsFluentImpl.LocalityLbSettingNestedImpl(item);
  }
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editLocalityLbSetting() {
    return withNewLocalityLbSettingLike(getLocalityLbSetting());
  }
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editOrNewLocalityLbSetting() {
    return withNewLocalityLbSettingLike(getLocalityLbSetting() != null ? getLocalityLbSetting(): new LocalityLoadBalancerSettingBuilder().build());
  }
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editOrNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return withNewLocalityLbSettingLike(getLocalityLbSetting() != null ? getLocalityLbSetting(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsFluentImpl that = (LoadBalancerSettingsFluentImpl) o;
    if (lbPolicy != null ? !lbPolicy.equals(that.lbPolicy) :that.lbPolicy != null) return false;
    if (localityLbSetting != null ? !localityLbSetting.equals(that.localityLbSetting) :that.localityLbSetting != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lbPolicy,  localityLbSetting,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lbPolicy != null) { sb.append("lbPolicy:"); sb.append(lbPolicy + ","); }
    if (localityLbSetting != null) { sb.append("localityLbSetting:"); sb.append(localityLbSetting); }
    sb.append("}");
    return sb.toString();
  }
  class LoadBalancerSettingsSimpleLbPolicyNestedImpl<N> extends LoadBalancerSettingsSimpleFluentImpl<LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<N>> implements LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<N>,Nested<N>{
    LoadBalancerSettingsSimpleLbPolicyNestedImpl(LoadBalancerSettingsSimple item) {
      this.builder = new LoadBalancerSettingsSimpleBuilder(this, item);
    }
    LoadBalancerSettingsSimpleLbPolicyNestedImpl() {
      this.builder = new LoadBalancerSettingsSimpleBuilder(this);
    }
    LoadBalancerSettingsSimpleBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluentImpl.this.withLbPolicy(builder.build());
    }
    public N endLoadBalancerSettingsSimpleLbPolicy() {
      return and();
    }
    
  }
  class LoadBalancerSettingsConsistentHashLbPolicyNestedImpl<N> extends LoadBalancerSettingsConsistentHashFluentImpl<LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<N>> implements LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<N>,Nested<N>{
    LoadBalancerSettingsConsistentHashLbPolicyNestedImpl(LoadBalancerSettingsConsistentHash item) {
      this.builder = new LoadBalancerSettingsConsistentHashBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLbPolicyNestedImpl() {
      this.builder = new LoadBalancerSettingsConsistentHashBuilder(this);
    }
    LoadBalancerSettingsConsistentHashBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluentImpl.this.withLbPolicy(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLbPolicy() {
      return and();
    }
    
  }
  class LocalityLbSettingNestedImpl<N> extends LocalityLoadBalancerSettingFluentImpl<LoadBalancerSettingsFluent.LocalityLbSettingNested<N>> implements LoadBalancerSettingsFluent.LocalityLbSettingNested<N>,Nested<N>{
    LocalityLbSettingNestedImpl(LocalityLoadBalancerSetting item) {
      this.builder = new LocalityLoadBalancerSettingBuilder(this, item);
    }
    LocalityLbSettingNestedImpl() {
      this.builder = new LocalityLoadBalancerSettingBuilder(this);
    }
    LocalityLoadBalancerSettingBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluentImpl.this.withLocalityLbSetting(builder.build());
    }
    public N endLocalityLbSetting() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsFluentImpl<A extends LoadBalancerSettingsFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsFluent<A>{
  public LoadBalancerSettingsFluentImpl() {
  }
  public LoadBalancerSettingsFluentImpl(LoadBalancerSettings instance) {
    if (instance != null) {
      this.withLbPolicy(instance.getLbPolicy());
      this.withLocalityLbSetting(instance.getLocalityLbSetting());
    }
  }
  private VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> lbPolicy;
  private LocalityLoadBalancerSettingBuilder localityLbSetting;
  
  /**
   * This method has been deprecated, please use method buildLbPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsLoadBalancerSettingsLbPolicy getLbPolicy() {
    return this.lbPolicy!=null?this.lbPolicy.build():null;
  }
  public IsLoadBalancerSettingsLbPolicy buildLbPolicy() {
    return this.lbPolicy!=null?this.lbPolicy.build():null;
  }
  public A withLbPolicy(IsLoadBalancerSettingsLbPolicy lbPolicy) {
    if (lbPolicy==null){ this.lbPolicy = null; _visitables.remove("lbPolicy"); return (A) this;}
    if (lbPolicy instanceof LoadBalancerSettingsSimple){ this.lbPolicy= new LoadBalancerSettingsSimpleBuilder((LoadBalancerSettingsSimple)lbPolicy); _visitables.get("lbPolicy").clear(); _visitables.get("lbPolicy").add(this.lbPolicy);}
    if (lbPolicy instanceof LoadBalancerSettingsConsistentHash){ this.lbPolicy= new LoadBalancerSettingsConsistentHashBuilder((LoadBalancerSettingsConsistentHash)lbPolicy); _visitables.get("lbPolicy").clear(); _visitables.get("lbPolicy").add(this.lbPolicy);}
    VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> builder = builderOf(lbPolicy); _visitables.get("lbPolicy").clear();_visitables.get("lbPolicy").add(builder);this.lbPolicy = builder;
    return (A) this;
  }
  public Boolean hasLbPolicy() {
    return this.lbPolicy != null;
  }
  public A withLoadBalancerSettingsSimpleLbPolicy(LoadBalancerSettingsSimple loadBalancerSettingsSimpleLbPolicy) {
    _visitables.get("lbPolicy").remove(this.lbPolicy);
    if (loadBalancerSettingsSimpleLbPolicy!=null){ this.lbPolicy= new LoadBalancerSettingsSimpleBuilder(loadBalancerSettingsSimpleLbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);} else { this.lbPolicy = null; _visitables.get("lbPolicy").remove(this.lbPolicy); } return (A) this;
  }
  public LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicy() {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNestedImpl();
  }
  public LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicyLike(LoadBalancerSettingsSimple item) {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNestedImpl(item);
  }
  public A withLoadBalancerSettingsConsistentHashLbPolicy(LoadBalancerSettingsConsistentHash loadBalancerSettingsConsistentHashLbPolicy) {
    _visitables.get("lbPolicy").remove(this.lbPolicy);
    if (loadBalancerSettingsConsistentHashLbPolicy!=null){ this.lbPolicy= new LoadBalancerSettingsConsistentHashBuilder(loadBalancerSettingsConsistentHashLbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);} else { this.lbPolicy = null; _visitables.get("lbPolicy").remove(this.lbPolicy); } return (A) this;
  }
  public LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicy() {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNestedImpl();
  }
  public LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicyLike(LoadBalancerSettingsConsistentHash item) {
    return new LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNestedImpl(item);
  }
  
  /**
   * This method has been deprecated, please use method buildLocalityLbSetting instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalityLoadBalancerSetting getLocalityLbSetting() {
    return this.localityLbSetting!=null ?this.localityLbSetting.build():null;
  }
  public LocalityLoadBalancerSetting buildLocalityLbSetting() {
    return this.localityLbSetting!=null ?this.localityLbSetting.build():null;
  }
  public A withLocalityLbSetting(LocalityLoadBalancerSetting localityLbSetting) {
    _visitables.get("localityLbSetting").remove(this.localityLbSetting);
    if (localityLbSetting!=null){ this.localityLbSetting= new LocalityLoadBalancerSettingBuilder(localityLbSetting); _visitables.get("localityLbSetting").add(this.localityLbSetting);} else { this.localityLbSetting = null; _visitables.get("localityLbSetting").remove(this.localityLbSetting); } return (A) this;
  }
  public Boolean hasLocalityLbSetting() {
    return this.localityLbSetting != null;
  }
  public LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<A> withNewLocalityLbSetting() {
    return new LoadBalancerSettingsFluentImpl.LocalityLbSettingNestedImpl();
  }
  public LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<A> withNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return new LoadBalancerSettingsFluentImpl.LocalityLbSettingNestedImpl(item);
  }
  public LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<A> editLocalityLbSetting() {
    return withNewLocalityLbSettingLike(getLocalityLbSetting());
  }
  public LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<A> editOrNewLocalityLbSetting() {
    return withNewLocalityLbSettingLike(getLocalityLbSetting() != null ? getLocalityLbSetting(): new LocalityLoadBalancerSettingBuilder().build());
  }
  public LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<A> editOrNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return withNewLocalityLbSettingLike(getLocalityLbSetting() != null ? getLocalityLbSetting(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsFluentImpl that = (LoadBalancerSettingsFluentImpl) o;
    if (!java.util.Objects.equals(lbPolicy, that.lbPolicy)) return false;

    if (!java.util.Objects.equals(localityLbSetting, that.localityLbSetting)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lbPolicy,  localityLbSetting,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lbPolicy != null) { sb.append("lbPolicy:"); sb.append(lbPolicy + ","); }
    if (localityLbSetting != null) { sb.append("localityLbSetting:"); sb.append(localityLbSetting); }
    sb.append("}");
    return sb.toString();
  }
  class LoadBalancerSettingsSimpleLbPolicyNestedImpl<N> extends LoadBalancerSettingsSimpleFluentImpl<LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNested<N>> implements LoadBalancerSettingsFluentImpl.LoadBalancerSettingsSimpleLbPolicyNested<N>,Nested<N>{
    LoadBalancerSettingsSimpleLbPolicyNestedImpl(LoadBalancerSettingsSimple item) {
      this.builder = new LoadBalancerSettingsSimpleBuilder(this, item);
    }
    LoadBalancerSettingsSimpleLbPolicyNestedImpl() {
      this.builder = new LoadBalancerSettingsSimpleBuilder(this);
    }
    LoadBalancerSettingsSimpleBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluentImpl.this.withLbPolicy(builder.build());
    }
    public N endLoadBalancerSettingsSimpleLbPolicy() {
      return and();
    }
    
  }
  class LoadBalancerSettingsConsistentHashLbPolicyNestedImpl<N> extends LoadBalancerSettingsConsistentHashFluentImpl<LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNested<N>> implements LoadBalancerSettingsFluentImpl.LoadBalancerSettingsConsistentHashLbPolicyNested<N>,Nested<N>{
    LoadBalancerSettingsConsistentHashLbPolicyNestedImpl(LoadBalancerSettingsConsistentHash item) {
      this.builder = new LoadBalancerSettingsConsistentHashBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLbPolicyNestedImpl() {
      this.builder = new LoadBalancerSettingsConsistentHashBuilder(this);
    }
    LoadBalancerSettingsConsistentHashBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluentImpl.this.withLbPolicy(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLbPolicy() {
      return and();
    }
    
  }
  class LocalityLbSettingNestedImpl<N> extends LocalityLoadBalancerSettingFluentImpl<LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<N>> implements LoadBalancerSettingsFluentImpl.LocalityLbSettingNested<N>,Nested<N>{
    LocalityLbSettingNestedImpl(LocalityLoadBalancerSetting item) {
      this.builder = new LocalityLoadBalancerSettingBuilder(this, item);
    }
    LocalityLbSettingNestedImpl() {
      this.builder = new LocalityLoadBalancerSettingBuilder(this);
    }
    LocalityLoadBalancerSettingBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluentImpl.this.withLocalityLbSetting(builder.build());
    }
    public N endLocalityLbSetting() {
      return and();
    }
    
  }
  
}
